@@ -1,5 +1,5 @@
 // gi imports
-const Tb = imports.gi.Tb;
+const TheBoard = imports.gi.TheBoard;
 
 function Background(args) {
     this._init(args);
@@ -26,10 +26,10 @@ Background.prototype = {
 
     _createMainBox : function() {
         this._mainBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         name: "background-main-box" });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               name: "background-main-box" });
     },
 
     _setContent : function(content) {
@@ -41,7 +41,7 @@ Background.prototype = {
 
         if (this._content) {
             this._mainBox.append(this._content.contentActor,
-                                 Tb.BoxPackFlags.EXPAND);
+                                 TheBoard.BoxPackFlags.EXPAND);
         }
     },
 
