@@ -606,7 +606,9 @@ MainWindow.prototype = {
     },
 
     _doAction : function(actionName, actionArgs) {
-        if (actionName == "setCurrentPage") {
+        if (actionName == "addNewPage") {
+            this._addNewPage();
+        } else if (actionName == "setCurrentPage") {
             this._setCurrentPage(actionArgs.pageModel);
         } else if (actionName == "setBackground") {
             this._currentPage.setBackground(actionArgs.backgroundId);
@@ -615,6 +617,11 @@ MainWindow.prototype = {
         }
     },
 
+    _addNewPage : function() {
+        let newPageModel = this._pageManager.addPageModel();
+        this._setCurrentPage(newPageModel);
+    },
+
     _setCurrentPage : function(pageModel) {
         if (this._currentPage &&
             this._currentPage.model.id == pageModel.id) {
@@ -790,12 +797,21 @@ MainWindow.prototype = {
 
         if (isControl && text == 'v') {
             this._pasteClipboardContent();
+            return true;
         } else if (isControl && text == 'a') {
             this._currentPage.selectAllThings();
+            return true;
         } else if (key == Clutter.Escape) {
             if (this._currentPage.selectedThings.length > 0) {
                 this._currentPage.unselectAllThings();
             }
+            return true;
+        } else if (key == Clutter.Delete) {
+            this._currentPage.doAction("remove");
+            return true;
+        } else if (isControl && text == 'n') {
+            this._addNewPage();
+            return true;
         } else if (text == 't') {
             this._currentPage.addThingFromState({ id: 'note' });
             return true;
