@@ -8,7 +8,7 @@ const Clutter = imports.gi.Clutter;
 const GIO = imports.gi.Gio;
 const GObject = imports.gi.GObject;
 const Mx = imports.gi.Mx;
-const Tb = imports.gi.Tb;
+const TheBoard = imports.gi.TheBoard;
 
 // util imports
 const MathUtil = imports.util.mathUtil;
@@ -73,12 +73,12 @@ Thing.prototype = {
 
     _createMainBox : function() {
         this._mainBox =
-            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
-                         xAlign: Tb.BoxAlignment.FILL,
-                         yAlign: Tb.BoxAlignment.FILL,
-                         width: this.initialWidth,
-                         height: this.initialHeight,
-                         reactive: true });
+            new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
+                               xAlign: TheBoard.BoxAlignment.FILL,
+                               yAlign: TheBoard.BoxAlignment.FILL,
+                               width: this.initialWidth,
+                               height: this.initialHeight,
+                               reactive: true });
 
         this._updateSelectedStyle();
 
@@ -131,11 +131,11 @@ Thing.prototype = {
                                   Lang.bind(this, this._onLinkButtonClicked));
 
         this._mainBox.append(this._linkButton,
-                             Tb.BoxPackFlags.FIXED);
+                             TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(this._linkButton,
-                                            Tb.BoxAlignment.START,
-                                            Tb.BoxAlignment.START);
+                                            TheBoard.BoxAlignment.START,
+                                            TheBoard.BoxAlignment.START);
     },
 
     _createRemoveButton : function() {
@@ -150,11 +150,11 @@ Thing.prototype = {
                                   Lang.bind(this, this._onRemoveButtonClicked));
 
         this._mainBox.append(this._removeButton,
-                             Tb.BoxPackFlags.FIXED);
+                             TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(this._removeButton,
-                                            Tb.BoxAlignment.END,
-                                            Tb.BoxAlignment.START);
+                                            TheBoard.BoxAlignment.END,
+                                            TheBoard.BoxAlignment.START);
     },
 
     _createResizeButton : function() {
@@ -180,11 +180,11 @@ Thing.prototype = {
         this._resizeButton.add_action(dragAction);
 
         this._mainBox.append(this._resizeButton,
-                             Tb.BoxPackFlags.FIXED);
+                             TheBoard.BoxPackFlags.FIXED);
 
         this._mainBox.set_fixed_child_align(this._resizeButton,
-                                            Tb.BoxAlignment.END,
-                                            Tb.BoxAlignment.END);
+                                            TheBoard.BoxAlignment.END,
+                                            TheBoard.BoxAlignment.END);
     },
 
     _updatePosition : function(newX, newY) {
@@ -220,7 +220,7 @@ Thing.prototype = {
 
         if (this._content) {
             this._mainBox.append(this._content.contentActor,
-                                 Tb.BoxPackFlags.EXPAND);
+                                 TheBoard.BoxPackFlags.EXPAND);
 
             this._removeButton.raise(this._content.contentActor);
             this._linkButton.raise(this._content.contentActor);
@@ -302,7 +302,7 @@ Thing.prototype = {
     },
 
     _onMainBoxDragMotion : function(action, actor, deltaX, deltaY) {
-        Tb.signal_stop_emission_by_name(action, "drag-motion");
+        TheBoard.signal_stop_emission_by_name(action, "drag-motion");
         this.emit("drag-motion", deltaX, deltaY);
     },
 
@@ -349,7 +349,7 @@ Thing.prototype = {
     },
 
     _onResizeButtonDragMotion : function(action, actor, deltaX, deltaY) {
-        Tb.signal_stop_emission_by_name(action, "drag-motion");
+        TheBoard.signal_stop_emission_by_name(action, "drag-motion");
 
         let newWidth = this._mainBox.width + deltaX;
         let newHeight = this._mainBox.height + deltaY;
