@@ -31,8 +31,8 @@ const _CASSETE_IMAGE = Path.THINGS_DATA_DIR + "sound/cassete.png";
 
 const _SHOW_BUTTON_BOX_TIME = 0.5;
 
-const _CAPTION_BOX_STYLE_NORMAL = "sound-thing-caption-box";
-const _CAPTION_BOX_STYLE_RECORDING = "sound-thing-caption-box-recording";
+const _CAPTION_BOX_NAME_NORMAL = "sound-thing-caption-box";
+const _CAPTION_BOX_NAME_RECORDING = "sound-thing-caption-box-recording";
 
 // Magic numbers based on the graphics of the
 // compact cassete
@@ -73,10 +73,9 @@ SoundThing.prototype = {
             new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
                                xAlign: TheBoard.BoxAlignment.FILL,
                                yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
                                name: "sound-thing-sound-box" });
 
-        this._soundBox.set_style(this._style);
-
         this._createCasseteBg();
         this._createContentBox();
     },
@@ -114,10 +113,9 @@ SoundThing.prototype = {
             new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
                                xAlign: TheBoard.BoxAlignment.FILL,
                                yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
                                name: "sound-thing-content-box" });
 
-        this._contentBox.set_style(this._style);
-
         this._createControlsBox();
 
         this._soundBox.append(this._contentBox,
@@ -129,10 +127,9 @@ SoundThing.prototype = {
             new TheBoard.Box({ orientation: TheBoard.BoxOrientation.VERTICAL,
                                xAlign: TheBoard.BoxAlignment.FILL,
                                yAlign: TheBoard.BoxAlignment.START,
+                               style: this._style,
                                name: "sound-thing-controls-box" });
 
-        this._controlsBox.set_style(this._style);
-
         this._createPlaybackBox();
         this._createTimeLabel();
 
@@ -151,10 +148,9 @@ SoundThing.prototype = {
                                yAlign: TheBoard.BoxAlignment.CENTER,
                                visible: false,
                                opacity: 0,
+                               style: this._style,
                                name: "sound-thing-playback-box" });
 
-        this._playbackBox.set_style(this._style);
-
         this._createPlayButton();
         this._createProgressBar();
 
@@ -165,10 +161,9 @@ SoundThing.prototype = {
     _createPlayButton : function() {
         this._playButton =
             new Mx.Button({ isToggle: true,
+                            style: this._style,
                             name: "sound-thing-play-button" });
 
-        this._playButton.set_style(this._style);
-
         this._playButton.connect("notify::toggled",
                                  Lang.bind(this,
                                            this._onPlayButtonToggled));
@@ -181,10 +176,9 @@ SoundThing.prototype = {
         this._progressBar =
             new Mx.ProgressBar({ reactive: true,
                                  height: 12,
+                                 style: this._style,
                                  name: "sound-thing-progress-bar" });
 
-        this._progressBar.set_style(this._style);
-
         this._updateProgressBar();
 
         this._progressBar.connect("button-press-event",
@@ -205,10 +199,9 @@ SoundThing.prototype = {
                            anchorY: -2,
                            visible: false,
                            opacity: 0,
+                           style: this._style,
                            name: "sound-thing-time-label" });
 
-        this._timeLabel.set_style(this._style);
-
         this._updateTimeLabel(this._player.duration);
 
         this._controlsBox.append(this._timeLabel,
@@ -224,16 +217,14 @@ SoundThing.prototype = {
             new TheBoard.Box({ orientation: TheBoard.BoxOrientation.HORIZONTAL,
                                xAlign: TheBoard.BoxAlignment.FILL,
                                yAlign: TheBoard.BoxAlignment.FILL,
-                               name: _CAPTION_BOX_STYLE_NORMAL });
-
-        this._captionBox.set_style(this._style);
+                               style: this._style,
+                               name: _CAPTION_BOX_NAME_NORMAL });
 
         this._captionLabel =
             new Mx.Label({ xAlign: Mx.Align.MIDDLE,
+                           style: this._style,
                            name: "sound-thing-caption-label" });
 
-        this._captionLabel.set_style(this._style);
-
         this._captionLabel.clutterText.maxLength = 25;
         this._captionLabel.clutterText.lineAlignment = Pango.Alignment.CENTER;
 
@@ -257,18 +248,16 @@ SoundThing.prototype = {
                                y: _SPOOLS_Y,
                                xAlign: TheBoard.BoxAlignment.FILL,
                                yAlign: TheBoard.BoxAlignment.FILL,
+                               style: this._style,
                                name: "sound-thing-spools-box" });
 
-        this._spoolsBox.set_style(this._style);
-
         for (let i = 0; i < 2; i++) {
             let spool = new Mx.Spinner({ width: 27,
                                         height: 27,
                                         animating: false,
+                                        style: this._style,
                                         name: "sound-thing-spool" });
 
-            spool.set_style(this._style);
-
             this._spoolsBox.append(spool,
                                    TheBoard.BoxPackFlags.NONE);
         }
@@ -420,14 +409,13 @@ SoundThing.prototype = {
         this._stopButton =
             new Mx.Button({ label: Gettext.gettext("Stop"),
                             y: _STOP_BUTTON_Y,
+                            style: this._style,
                             name: "sound-thing-stop-button" });
 
         this._stopButton.connect("clicked",
                                  Lang.bind(this,
                                            this._onStopButtonClicked));
 
-        this._stopButton.set_style(this._style);
-
         this._contentBox.append(this._stopButton,
                                 TheBoard.BoxPackFlags.FIXED);
 
@@ -439,7 +427,7 @@ SoundThing.prototype = {
 
         this._setSpoolsAnimating(true);
 
-        this._captionBox.name = _CAPTION_BOX_STYLE_RECORDING;
+        this._captionBox.name = _CAPTION_BOX_NAME_RECORDING;
 
         this._stopEditingCaption();
         this._textBeforeRecording = this._captionLabel.text;
@@ -463,7 +451,7 @@ SoundThing.prototype = {
         this._stopButton.destroy();
         delete this._stopButton;
 
-        this._captionBox.name = _CAPTION_BOX_STYLE_NORMAL;
+        this._captionBox.name = _CAPTION_BOX_NAME_NORMAL;
 
         this._captionLabel.text = this._textBeforeRecording;
         delete this._textBeforeRecording;
