@@ -14,11 +14,11 @@
 MxPadding *
 tb_mx_stylable_get_padding (MxStylable *stylable)
 {
-  GValue padding;
+  MxPadding *padding;
 
-  g_value_init (&padding, MX_TYPE_PADDING);
+  mx_stylable_get (stylable,
+                   "padding", &padding,
+                   NULL);
 
-  mx_stylable_get_property (stylable, "padding", &padding);
-
-  return g_value_get_boxed (&padding);
+  return padding;
 }
